@@ -291,27 +291,28 @@ clean.multi_alleles <- function(A1,A2,REF,ALT,AF)
 
 getMultiAlleleCountTbl <- function(input.data) {
 
-  tbl <- input.data[,.N, keyby=.(VT,is.na(REF), MULTI_ALLELIC)]
+  # tbl <- input.data[,.N, keyby=.(VT,is.na(REF), MULTI_ALLELIC)]
+  tbl <- input.data[,.N, keyby=.(VT,(SOURCE != "Std_ref" | is.na(SOURCE)), MULTI_ALLELIC)]
 
   tbl <- t(data.table(
-   'Bi-allelic SNP' =  ifelse(length(tbl[VT == 1 & !(is.na) & !MULTI_ALLELIC,N]) == 0 ,
+   'Bi-allelic SNP' =  ifelse(length(tbl[VT == 1 & !(SOURCE) & !MULTI_ALLELIC,N]) == 0 ,
                                 '0',
-                                format(tbl[VT == 1 & !(is.na) & !MULTI_ALLELIC,N],big.mark = ',',scientific = FALSE)),
-    'Multi-allelic SNP' =  ifelse(length(tbl[VT == 1 & !(is.na) & MULTI_ALLELIC,N]) == 0 ,
+                                format(tbl[VT == 1 & !(SOURCE) & !MULTI_ALLELIC,N],big.mark = ',',scientific = FALSE)),
+    'Multi-allelic SNP' =  ifelse(length(tbl[VT == 1 & !(SOURCE) & MULTI_ALLELIC,N]) == 0 ,
                                   '0' ,
-                                  format(tbl[VT == 1 & !(is.na) & MULTI_ALLELIC,N],big.mark = ',',scientific = FALSE)),
-    'SNPs not found in standard reference dataset' =  ifelse(length(tbl[VT == 1 & (is.na) ,N]) == 0 ,
+                                  format(tbl[VT == 1 & !(SOURCE) & MULTI_ALLELIC,N],big.mark = ',',scientific = FALSE)),
+    'SNPs not found in standard reference dataset' =  ifelse(length(tbl[VT == 1 & (SOURCE) ,N]) == 0 ,
                                   '0' ,
-                                  format(tbl[VT == 1 & (is.na),N],big.mark = ',',scientific = FALSE)),
-    'Bi-allelic INDEL' = ifelse(length(tbl[VT == 2 & !(is.na) & !MULTI_ALLELIC,N]) == 0 ,
+                                  format(tbl[VT == 1 & (SOURCE),N],big.mark = ',',scientific = FALSE)),
+    'Bi-allelic INDEL' = ifelse(length(tbl[VT == 2 & !(SOURCE) & !MULTI_ALLELIC,N]) == 0 ,
                                 '0' ,
-                                format( tbl[VT == 2 & !(is.na) & !MULTI_ALLELIC,N],big.mark = ',',scientific = FALSE)),
-    'Multi-allelic INDEL' =  ifelse(length(tbl[VT == 2 & !(is.na) & MULTI_ALLELIC,N]) == 0 ,
+                                format( tbl[VT == 2 & !(SOURCE) & !MULTI_ALLELIC,N],big.mark = ',',scientific = FALSE)),
+    'Multi-allelic INDEL' =  ifelse(length(tbl[VT == 2 & !(SOURCE) & MULTI_ALLELIC,N]) == 0 ,
                                     '0' ,
-                                    format(tbl[VT == 2 & !(is.na) & MULTI_ALLELIC,N],big.mark = ',',scientific = FALSE)),
-    'INDELs not found in standard reference dataset' =  ifelse(length(tbl[VT == 2 & (is.na) ,N]) == 0 ,
+                                    format(tbl[VT == 2 & !(SOURCE) & MULTI_ALLELIC,N],big.mark = ',',scientific = FALSE)),
+    'INDELs not found in standard reference dataset' =  ifelse(length(tbl[VT == 2 & (SOURCE) ,N]) == 0 ,
                                    '0' ,
-                                   format(tbl[VT == 2 & (is.na) ,N],big.mark = ',',scientific = FALSE))
+                                   format(tbl[VT == 2 & (SOURCE) ,N],big.mark = ',',scientific = FALSE))
   ))
 
   colnames(tbl) <- 'count'
